@@ -23,8 +23,14 @@
 
 #ifndef AKONADI_KCAL_DEPRECATED
 #  define AKONADI_KCAL_DEPRECATED __attribute__ ((__deprecated__))
-#  define AKONADI_KCAL_DEPRECATED_EXPORT AKONADI_KCAL_EXPORT __attribute__ ((__deprecated__))
-#  define AKONADI_KCAL_DEPRECATED_NO_EXPORT AKONADI_KCAL_NO_EXPORT __attribute__ ((__deprecated__))
+#endif
+
+#ifndef AKONADI_KCAL_DEPRECATED_EXPORT
+#  define AKONADI_KCAL_DEPRECATED_EXPORT AKONADI_KCAL_EXPORT AKONADI_KCAL_DEPRECATED
+#endif
+
+#ifndef AKONADI_KCAL_DEPRECATED_NO_EXPORT
+#  define AKONADI_KCAL_DEPRECATED_NO_EXPORT AKONADI_KCAL_NO_EXPORT AKONADI_KCAL_DEPRECATED
 #endif
 
 #define DEFINE_NO_DEPRECATED 0
